/*! \file generators_b.h
    \brief Hier werden einige Zufallsgeneratoren definiert

 */
#ifndef _GENERATORS_B_H
#define _GENERATORS_B_H

#include <math.h>
#include <stdlib.h>
/*! \fn float ran0(long *idum)
    \brief Der Zufallszahlengenerator RAN0

   Generator  RAN0
    
   Quelle: Numerical Recipes in C 2nd edition  (Press et al 1992)  S. 278f
           Autoren: Park and Miller, Communications of the ACM 31, 1192 (1988).

   Anmerkung Sormann: dieser Generator wird in den Numerical Recipes
                      als "Minimal Standard Generator" bezeichnet.

                      Periode = 2**31-2 = 2147483646

                      SEED = jeder INTEGER-Wert ausser  123459876

                      Probleme: der Generator ist korrelationsanfaellig,
                      wenn die Zahl der random numbers > 10**7 wird.
*/   
float ran0(long *idum);
/*! \fn float ran1(long *idum)
   \brief Der Zufallszahlengenerator RAN1

   Generator  RAN1    
   Quelle: Numerical Recipes in C 2nd edition  (Press et al 1992)  S. 280f
           Kombination des Park-Miller-Generators mit dem Bays-Durham Shuffle.

   Anmerkung Sormann: Laut Aussage von Press et al besteht dieser Generator 
                      sehr viele statistische Tests, solange die Zahl der
                      berechneten random numbers 10**8 nicht uebersteigt.

                      Periode = ca. 2 . 10**9

                      SEED = jeder NEGATIVE INTEGER-Wert 
 */
float ran1(long *idum);
/*! \fn float ran2(long *idum)
    \brief Der Zufallszahlengenerator RAN2

    Generator  RAN2    
   Quelle: Numerical Recipes in C 2nd edition  (Press et al 1992)  S. 282f
           Generators von L'Ecuyer mit dem Bays-Durham Shuffle.
           (L'Ecuyer, Communications of the ACM 31, 742 (1988)).

   Anmerkung Sormann: Press et al sind von diesem Generator so ueberzeugt,
                      dass sie demjenigen, der mittels eines statistischen
                      Tests ein Fehlverhalten des Generators nachweist,
                      1000 US Dollar bezahlen. 

                      Periode = ca. 2.3 . 10**18   (!!)

                      SEED = jeder NEGATIVE INTEGER-Wert 
 */
float ran2(long *idum);
/*! \fn float ranbh(long *ibm)
    \brief Der Zufallszahlengenerator RANBH

     Generator RANBH:
     Random number generator fuer [0,1] nach Binder-Heermann, 
     "Monte-Carlo Simulation in Statistical Physics", Springer 1988, S.76

     At first CALL, IBM must be an ODD INTEGER !!
 */
float ranbh(long *ibm);
float shuffle(long *idum);
unsigned int mzran13();
void ran13set(unsigned int xx, unsigned int yy, unsigned int zz, int nn);
float mzruni();
#endif
